#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5724-M24
# (C) Copyright IBM Corporation 2011, 2016. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Data migration from V6.1/6.2/7.0 to V7.5
#*************************************************************************
#END COPYRIGHT

USER_PROPS=$*
CUR_DIR=`pwd`
SH_R_DIR=`dirname ${0}`
cd "$SH_R_DIR/../../../"
WAS_HOME=`pwd`
export WAS_HOME
cd "$CUR_DIR"

SYS_PROPS=-Djava.util.logging.config.file="$WAS_HOME"/scripts.wbm/migration/DataMigration/logging.properties
MY_CLASSPATH=$WAS_HOME/scripts.wbm/migration/DataMigration/com.ibm.wbimonitor.datamigration.jar:$WAS_HOME/plugins/com.ibm.wbimonitor.lifecycle.spi.jar:$WAS_HOME/plugins/com.ibm.wbimonitor.persistence.jar:$WAS_HOME/jdbcdrivers/DB2/db2jcc_license_cisuz.jar:$WAS_HOME/jdbcdrivers/DB2/db2jcc_license_cu.jar:$WAS_HOME/jdbcdrivers/DB2/db2jcc4.jar:$WAS_HOME/jdbcdrivers/Oracle/ojdbc6.jar:$WAS_HOME/jdbcdrivers/SQLServer/sqljdbc4.jar

cd "$WAS_HOME"/scripts.wbm/migration/DataMigration

#######################################################
#                                                     #
# Usage                                               #
#                                                     #
#######################################################
usage () {
  echo  ""
  echo  "Usage:"
  echo  "DataMigration -dbType <database type> -dbName <database name> -dbSchema <schema name> "
  echo  "              -host  <hostname of database> -port <database port> "
  echo  "              -dbUser <user name of database> -dbPassword <password of database> "
  echo  "              [-dbDriverType <JDBC driver type, only for DB2ZOS>]"              
  echo  ""
  echo  "Where:"
  echo  "-dbType(required):"
  echo  "     Database type of the monitor database, the value may be: DB2/Oracle/SQLServer/DB2ZOS."
  echo  ""
  echo  "-dbName(required):"
  echo  "     Name of the monitor database."
  echo  ""
  echo  "-dbSchema(required):"
  echo  "      Schema name of the monitor database."
  echo  ""
  echo  "-host(required):"
  echo  "     Host name or IP address of the monitor database."  
  echo  "" 
  echo  "-port(required):"
  echo  "     The port of monitor database. This parameter is necessary"
  echo  ""
  echo  "-dbUser(required):"
  echo  "     User name that is authorized to access monitor database."
  echo  ""
  echo  "-dbPassword(required):"
  echo  "     Password that is authorized to access monitor databae."  
  echo  ""
  echo  "-dbDriverType(optional):"
  echo  "     JDBC driver type that is used to connect to database, this parameter is necessary only when database type is DB2ZOS."
  echo  "     The value should be 2 when it's local database, otherwise the value should be 4."
  echo  ""
  echo  "Usage Example:"
  echo  "DataMigration.sh -dbType DB2 -dbName MONITOR -dbSchema MONITOR -host localhost -port 50000 -dbUser db2admin -dbPassword db2pwd"  
  echo  ""
  exit 1
 }   
 
if [ $# -gt 16 ]; then
  usage
fi
  
while [ $# -gt 0 ]; do
  case $1 in
    -dbType) dbType=$2; shift; shift;;
    -dbName) dbName=$2; shift; shift;;
    -dbSchema) dbSchema=$2; shift; shift;;
    -host) hostName=$2; shift; shift;;
    -port) port=$2; shift; shift;;
    -dbUser) dbUser=$2; shift; shift;;
    -dbPassword) dbPassword=$2; shift; shift;;
    -dbDriverType) dbDriverType=$2; shift; shift;;
    -h) usage;;
    *) usage;;
  esac;
done

"$WAS_HOME"/java/bin/java -classpath "$MY_CLASSPATH" $SYS_PROPS  com.ibm.wbimonitor.datamigration.DataMigration $dbType $dbName $dbSchema $hostName $port $dbUser $dbPassword $dbDriverType
if [ $? -gt 0 ]; 
  then    
    exit 1
  else  	
	exit 0
fi